Entity

Enum Entity 

pub enum Entity {
    BinarySensor(BinarySensor),
}
Represents different types of entities supported by ESPHome.

This enum contains all entity types that can be registered with the server. Currently, only binary sensors are implemented, but this will expand to include other entity types like switches, lights, sensors, etc.

Variants



BinarySensor(BinarySensor)

A binary sensor entity (on/off state)