Module hash

Module hash 

Hash utilities for generating stable 32-bit identifiers.

This module implements a 32-bit FNV-1 hash function with specific preprocessing steps just like the ESPHome native API uses for generating entity keys from object IDs.

Functions

hash_fnv1
Compute the 32-bit FNV-1 hash of a name after applying a snake-case and sanitization pass.