Home of all automatically generated proto modules. Contains the versioned modules that are activated by default or via the feature flags.
Re-exports
pub use version_2025_12_1::*;
Home of all automatically generated proto modules. Contains the versioned modules that are activated by default or via the feature flags.
pub use version_2025_12_1::*;